@@ -3,6 +3,7 @@ package DBIx::Class::EncodedColumn::Crypt::Eksblowfish::Bcrypt;
 use strict;
 use warnings;
 use Crypt::Eksblowfish::Bcrypt ();
+use Encode qw(is_utf8 encode_utf8);
 
 our $VERSION = '0.00001';
 
@@ -24,6 +25,10 @@ sub make_encode_sub {
 
   my $encoder = sub {
     my ($plain_text, $settings_str) = @_;
+    if ( is_utf8($plain_text) ) {
+      #  Bcrypt expects octets
+      $plain_text = encode_utf8($plain_text);
+    }
     unless ( $settings_str ) {
       my $salt = join('', map { chr(int(rand(256))) } 1 .. 16);
       $salt = Crypt::Eksblowfish::Bcrypt::en_base64( $salt );
